searchData={"items":[{"type":"module","title":"Hypa","doc":"`Hypa` is a set of utilities for building applications that use [htmx](https://htmx.org/).\nIt provides the following modules:\n\n- `Hypa.Plug` - A `Plug` module that adds data from HTMX headers to `conn.assigns`.","ref":"Hypa.html"},{"type":"module","title":"Hypa.Plug","doc":"A `Plug` offering functions useful for applications using HTMX.\n\nIf you are using Phoenix, add this Plug to your browser pipeline:\n\n    pipeline :browser do\n      plug Hypa.Plug\n    end","ref":"Hypa.Plug.html"},{"type":"function","title":"Hypa.Plug.call/2","doc":"","ref":"Hypa.Plug.html#call/2"},{"type":"function","title":"Hypa.Plug.detect_htmx_request/2","doc":"Extracts HTMX headers into the conn's assigns.\n\nSee [Request Headers Reference] for documentation on HTMX's header values.\n\n[Request Headers Reference]: https://htmx.org/reference/#request_headers","ref":"Hypa.Plug.html#detect_htmx_request/2"},{"type":"function","title":"Examples - Hypa.Plug.detect_htmx_request/2","doc":"iex> conn(:get, \"/hello\")\n    ...> |> merge_req_headers([\n    ...>      {\"hx-request\", \"true\"},\n    ...>      {\"hx-current-url\", \"/current\"},\n    ...>      {\"hx-history-restore-request\", \"false\"},\n    ...>      {\"hx-target\", \"my-target-element-id\"},\n    ...>      {\"hx-trigger-name\", \"my-triggered-element-name\"},\n    ...>      {\"hx-trigger\", \"my-triggered-element-id\"}\n    ...>    ])\n    ...> |> Hypa.Plug.detect_htmx_request(Hypa.Plug.init([]))\n    ...> |> Map.get(:assigns)\n    ...> |> Map.get(:htmx)\n    %{\n      request: true,\n      boosted: false,\n      current_url: \"/current\",\n      history_restore_request: false,\n      prompt: nil,\n      target: \"my-target-element-id\",\n      trigger: \"my-triggered-element-id\",\n      trigger_name: \"my-triggered-element-name\"\n    }\n\nIf the request does not have HTMX headers, the `:htmx` assign will not be present.\n\n    iex> conn(:get, \"/htmxless\")\n    ...> |> Hypa.Plug.detect_htmx_request(Hypa.Plug.init([]))\n    ...> |> Map.get(:assigns)\n    ...> |> Map.has_key?(:htmx)\n    false","ref":"Hypa.Plug.html#detect_htmx_request/2-examples"},{"type":"function","title":"Hypa.Plug.init/1","doc":"","ref":"Hypa.Plug.html#init/1"},{"type":"extras","title":"Hypa","doc":"# Hypa\n\n[![Elixir build](https://github.com/Cantido/hypa/actions/workflows/elixir.yml/badge.svg)](https://github.com/Cantido/hypa/actions/workflows/elixir.yml)\n![Hex.pm Version](https://img.shields.io/hexpm/v/hypa)\n![Hex.pm License](https://img.shields.io/hexpm/l/hypa)\n[![hexdocs.pm](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/hypa/)\n\nUseful functions for Elixir applications using [htmx].\n\n[htmx]: https://htmx.org","ref":"readme.html"},{"type":"extras","title":"Installation - Hypa","doc":"This library is [available in Hex](https://hex.pm/packages/hypa), and the package can be installed\nby adding `hypa` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:hypa, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Hypa","doc":"Use [`Hypa.Plug`] to add htmx request headers to `conn.assigns`.\nAdd it to your `Plug` pipeline like this:\n\n```elixir\nplug Hypa.Plug\n```\n\nSee [the docs](https://hexdocs.pm/hypa) for more information.\n\n[`Hypa.Plug`]: https://hexdocs.pm/hypa/Hypa.Plug.html","ref":"readme.html#usage"},{"type":"extras","title":"License - Hypa","doc":"Copyright © 2024 Rosa Richter\n\nThis program is free software: you can redistribute it and/or modify\nit under the terms of the GNU Affero General Public License as\npublished by the Free Software Foundation, either version 3 of the\nLicense, or (at your option) any later version.\n\nThis program is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU Affero General Public License for more details.\n\nYou should have received a copy of the GNU Affero General Public License\nalong with this program.  If not, see  .","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}